library(ordBTL)
data(CEMSwide)

# Compute design matrix
columns <- colnames(CEMSwide)[grep("V",colnames(CEMSwide))]
comparison <- c("London Paris", "London Milano", "Paris Milano", 
                "London St.Gallen", "Paris St.Gallen", 
                "Milano St.Gallen", "London Barcelona",
                "Paris Barcelona", "Milano Barcelona", 
                "St.Gallen Barcelona", "London Stockholm", 
                "Paris Stockholm", "Milano Stockholm",
                "St.Gallen Stockholm", "Barcelona Stockholm")
CEMSlong <- wide2long(data=CEMSwide, paircomp=columns, 
                      names=comparison, v.names="Y")
des <- design(CEMSlong[-which(is.na(CEMSlong$Y)),], 
               var1="object1", var2="object2", 
               use.vars="ALL", reference="Stockholm")

# Formula for the model considering all subject-object interactions
form <- Y ~ 
  (GAMMA.London+GAMMA.Paris+GAMMA.Milano+GAMMA.StGallen+GAMMA.Barcelona)+
  (GAMMA.London+GAMMA.Paris+GAMMA.Milano+GAMMA.StGallen+GAMMA.Barcelona):
  (WOR+SEX+DEG+STUD+ENG+FRA+SPA+ITA)

# Variable selection procedure (runtime ~ 3 minutes)
BoostDev <- BTLboost(form, data=des, groupVars=c("WOR","DEG","SEX","STUD"), 
                     selection="DEVIANCE", mstop=35)
# you can use more boosting iterations (e.g. mstop=1000), however, the best
# iteration based on the BIC will be iteration 34.

# Refitting based on selected variables when the BIC is used as 
# stopping criterion 
selVars <- BoostDev$PATH[which.min(BoostDev$BIC),]
selForm <- as.formula(paste("Y~", paste(names(selVars[,!is.na(selVars)])[-1],
                                        collapse="+")))
refit <- ordBTL(selForm, data=des)
# Reproducing results of Table 4
getRank(refit)
